<?php


namespace ShopEngine_Pro\Modules\Pre_Order\Settings;


use ShopEngine_Pro\Traits\Singleton;

class Remaining_Order {

	use Singleton;

	/**
	 * Generate booked order amount once for a product
	 * keep generated list to array for performance optimizing.
	 * @var array
	 */
	private $list_generated = [] ;

	public function __construct() {

		add_filter( 'woocommerce_order_data_store_cpt_get_orders_query', [ $this, 'pre_order_query_modify' ], 10, 2 );
	}


	public function pre_order_query_modify( $query, $query_vars ): array {

		if ( isset( $query_vars['shopengine_pre_order_query'] ) &&  $query_vars['shopengine_pre_order_query'] ) {

			$query['meta_query'][] = [
				'key' => 'shopengine_pre_order',
				'value' => 'yes',
			];

		}

		return $query;
	}

	/**
	 * Get product total orders
	 *
	 * @since      2.5.0
	 * @access     private
	 * @param      int    $product_id
	 * @param      int    $variation_id
	 * @return     int
	 */
	private function get_product_total_orders( $product_id, $variation_id = null ): int {
		$args = array(
			'limit'       => -1,
			'status'      => array( 'completed', 'processing', 'on-hold' ), // Exclude 'wc-cancelled' and 'wc-refunded' statuses
			'return'      => 'ids',
			'meta_query'  => array(
				array(
					'key'   => '_product_id',
					'value' => intval( $product_id ),
					'compare' => '='
				),
			),
		);
	
		if ( $variation_id ) {
			$args['meta_query'][] = array(
				'key'   => '_variation_id',
				'value' => intval( $variation_id ),
				'compare' => '='
			);
		}
	
		$order_ids = wc_get_orders( $args );
	
		// Sum the quantities from order items
		$total_quantity = 0;
		foreach ( $order_ids as $order_id ) {
			$order = wc_get_order( $order_id );
			if ( $order ) {
				foreach ( $order->get_items() as $item ) {
					if ( isset( $item['product_id'] ) && intval( $item['product_id'] ) === intval( $product_id ) ) {
						if ( $variation_id ) {
							if ( isset( $item['variation_id'] ) && intval( $item['variation_id'] ) === intval( $variation_id ) ) {
								$total_quantity += intval( $item['qty'] );
							}
						} else {
							$total_quantity += intval( $item['qty'] );
						}
					}
				}
			}
		}
	
		return $total_quantity;
	}

	public function booked_Orders( $product_id , $variation_id = null): int {

		if( isset( $this->list_generated[ $product_id.$variation_id ] ) ){
			return $this->list_generated[ $product_id.$variation_id ] ;
		}


		$this->list_generated[ $product_id.$variation_id ] =  $this->get_product_total_orders( $product_id,$variation_id );


		return $this->list_generated[ $product_id.$variation_id ] ;
	}

}